=======================================================
An open-source toolkit for large-scale genomic analysis
=======================================================

|circle-ci|

.. |circle-ci| image:: https://circleci.com/gh/projectglow/glow.svg?style=svg&circle-token=7511f70b2c810a18e88b5c537b0410e82db8617d
    :target: https://circleci.com/gh/projectglow/glow

Glow is an open-source toolkit for working with genomic data at biobank-scale and beyond. The toolkit is natively built
on Apache Spark, the leading unified engine for big data processing and machine learning, enabling the scale of the
cloud for genomics workflows.

`Read the docs`_ to start using Glow.

.. _Read the docs: https://glow.readthedocs.io
